@@ -35,6 +35,14 @@ import time
 import multiprocessing
 import functools
 
+
+VERSION = "1.0.7"
+AUTHORS = '''\
+Olof Bjarnason, Fredrik Wendt, Krunoslav Saho,
+Samuel Ytterbrink, Rafael Capucho, Ilian Iliev,
+Henrik Bohre, Wari Wahab, Maximilien Riehl,
+Javier J. Gutiérrez'''
+HOMEPAGE = "http://pytddmon.org"
 ON_PYTHON3 = sys.version_info[0] == 3
 ON_WINDOWS = platform.system() == "Windows"
 
@@ -44,7 +52,8 @@ ON_WINDOWS = platform.system() == "Windows"
 ####
 
 class Pytddmon:
-    """The core class, all functionality (except UI) is combined into this class"""
+    """The core class, all functionality (except UI) is
+    combined into this class"""
 
     def __init__(
             self,
@@ -154,6 +163,7 @@ class Monitor:
         self.snapshot = new_snapshot
         return change_detected
 
+
 class Kata:
     ''' Generates a logical unit test template file '''
     def __init__(self, kata_name):
@@ -174,12 +184,13 @@ class {1}(unittest.TestCase):
 '''.format(kata_name, classname)
         self.filename = 'test_' + kata_name.lower().replace(' ', '_') + '.py'
 
+
 ####
 ## Finding files
 ####
-
 class FileFinder:
-    """Returns all files matching given regular expression from root downwards"""
+    """Returns all files matching given regular
+    expression from root downwards"""
 
     def __init__(self, root, regexp):
         self.root = os.path.abspath(root)
@@ -204,7 +215,6 @@ class FileFinder:
         return bool(re.match(self.regexp + "$", string_to_match))
 
 
-
 ####
 ## Finding & running tests
 ####
@@ -305,7 +315,10 @@ def run_suite(suite):
     result = text_test_runner.run(suite)
     green = result.testsRun - len(result.failures) - len(result.errors)
     total = result.testsRun
-    log = err_log.getvalue() if green < total else "All %i tests passed\n" % green
+    if green < total:
+        log = err_log.getvalue()
+    else:
+        log = "All %i tests passed\n" % total
     return green, total, log
 
 
@@ -321,10 +334,12 @@ def import_tkinter():
         else:
             import tkinter
     except ImportError as e:
-        sys.stderr.write('Cannot import tkinter. Please install it using your system ' +
-                         'package manager, since tkinter is not available on PyPI. On Ubuntu : ' +
-                         '`sudo apt-get install python-tk`.\n' +
-                         'The actual error was "{0}"\n'.format(e))
+        sys.stderr.write(
+            'Cannot import tkinter. Please install it using your system ' +
+            'package manager, since tkinter is not available on PyPI. ' +
+            ' In Ubuntu: \n' +
+            '    sudo apt-get install python-tk\n' +
+            'The actual error was "{0}"\n'.format(e))
         raise SystemExit(1)
     return tkinter
 
@@ -538,6 +553,7 @@ class TkGUI(object):
         self.loop()
         self.root.mainloop()
 
+
 class ColorPicker:
     """
     ColorPicker decides the background color the pytddmon window,
@@ -599,7 +615,9 @@ def parse_commandline():
     returns (files, test_mode) created from the command line arguments
     passed to pytddmon.
     """
-    parser = optparse.OptionParser()
+    usage = "usage: %prog [options] [static file list]"
+    version = "%prog " + VERSION
+    parser = optparse.OptionParser(usage=usage, version=version)
     parser.add_option(
         "--log-and-exit",
         action="store_true",
@@ -607,10 +625,12 @@ def parse_commandline():
         help='Run all tests, write the results to "pytddmon.log" and exit.')
     parser.add_option(
         "--log-path",
-        help='Instead of writing to "pytddmon.log" in --log-and-exit, write to LOG_PATH.')
+        help='Instead of writing to "pytddmon.log" in --log-and-exit, ' +
+             'write to LOG_PATH.')
     parser.add_option(
         "--gen-kata",
-        help='Generate a stub unit test file appropriate for jump starting a kata')
+        help='Generate a stub unit test file appropriate for jump ' +
+             'starting a kata')
     parser.add_option(
         "--no-pulse",
         dest="pulse_disabled",
@@ -650,7 +670,8 @@ def run():
     sys.path[:0] = [cwd]
 
     # Command line argument handling
-    (static_file_set, test_mode, test_output, pulse_disabled, kata_name) = parse_commandline()
+    (static_file_set, test_mode, test_output,
+     pulse_disabled, kata_name) = parse_commandline()
 
     # Generating a kata unit test file? Do it and exit ...
     if kata_name:
